| Fclusty | R Documentation |
Title
Fclusty(data, times, startK, endK, r, outfilename, verbose = FALSE)
data |
Enter the observation data matrix with dimension ????, and each row is an observation vector. |
times |
Enter the time series vector with the dimension ???? |
startK |
The initial number of clusters, of type integer, startK<endk< span=""></endk<> |
endK |
Maximum number of clusters. Type is integer |
r |
The order of an orthogonal polynomial of type integer |
outfilename |
String data describing the location and name prefix of the output file, The general format is: \ output file path \ Output file name prefix |
verbose |
Bool indicates whether to output running information |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.